@@ -46,7 +46,7 @@ class LaunchError(Exception):
     def __init__(self, error_msg):
         super(LaunchError, self).__init__()
 
-        self.error_msg = error_msg
+        self.error_msg = textwrap.shorten(error_msg, width=256)
 
 
 @XBlock.wants('settings')
